==> Zephyrus-3.0.3.11386.tar.gz: Zephyrus-3.0.3.11386/Zephyrus/blog_extension/migrations/0005_auto_20180805_2030.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blog_extension', '0004_auto_20180520_0328'),
    ]

    operations = [
        migrations.CreateModel(
            name='ViewCount',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('url', models.CharField(max_length=400, editable=False)),
                ('count', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='catagory',
            field=models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True, verbose_name='Catagory'),
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='limit',
            field=models.PositiveIntegerField(default=6, verbose_name='Limit'),
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='renderTemplate',
            field=models.CharField(default=b'blog_extension/Default.html', max_length=150, verbose_name='Render template', choices=[(b'blog_extension/Default.html', 'Default')]),
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='tag',
            field=models.ManyToManyField(default=None, to='taggit.Tag', null=True, verbose_name='Tag', blank=True),
        ),
    ]

==> Zephyrus-3.6.16.12006.tar.gz: Zephyrus-3.6.16.12006/Zephyrus/blog_extension/migrations/0005_auto_20180805_2030.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blog_extension', '0004_auto_20180520_0328'),
    ]

    operations = [
        migrations.CreateModel(
            name='ViewCount',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('url', models.CharField(max_length=400, editable=False)),
                ('count', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='catagory',
            field=models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True, verbose_name='Catagory', on_delete=models.CASCADE),
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='limit',
            field=models.PositiveIntegerField(default=6, verbose_name='Limit'),
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='renderTemplate',
            field=models.CharField(default=b'blog_extension/Default.html', max_length=150, verbose_name='Render template', choices=[(b'blog_extension/Default.html', 'Default')]),
        ),
        migrations.AlterField(
            model_name='filterplugin',
            name='tag',
            field=models.ManyToManyField(default=None, to='taggit.Tag', null=True, verbose_name='Tag', blank=True),
        ),
    ]
